<?php

namespace App\Models;

use CodeIgniter\Model;

class Student extends Model
{
    protected $DBGroup              = 'default';
    protected $table                = 'student';
    protected $primaryKey           = 'id_student';
    protected $useAutoIncrement     = true;
    protected $insertID             = 0;
    protected $returnType           = 'array';
    protected $useSoftDeletes       = false;
    protected $protectFields        = true;
    protected $allowedFields        = ['id_student','dob','identification', 'id_exam_center', 'totalwithoutaddl', 'excessover', 'id_user', 'id_year', 'name', 'father_name', 'dob-year', 'dob-month', 'dob-days', 'rollnumber', 'created_at', 'updated_at', 'gender', 'nameofschool', 'total', 'result', 'division', 'identitymark','course_name','course_month'];

    // Dates
    protected $useTimestamps        = false;
    protected $dateFormat           = 'datetime';
    protected $createdField         = 'created_at';
    protected $updatedField         = 'updated_at';
    protected $deletedField         = 'deleted_at';

    // Validation
    protected $validationRules      = [];
    protected $validationMessages   = [];
    protected $skipValidation       = false;
    protected $cleanValidationRules = true;

    // Callbacks
    protected $allowCallbacks       = true;
    protected $beforeInsert         = [];
    protected $afterInsert          = [];
    protected $beforeUpdate         = [];
    protected $afterUpdate          = [];
    protected $beforeFind           = [];
    protected $afterFind            = [];
    protected $beforeDelete         = [];
    protected $afterDelete          = [];

    public function getStudentDetails($limit, $offset, $total = false, $query = null, $id_year = null , $id_users = null, $course_name = null)
    {
        $builder = $this->db->table('student');
        $result = $builder
            ->select('exam_center.name as exam_center ,student.*')
            ->join('exam_center','exam_center.id_exam_center = student.id_exam_center','inner');
           
            
        if ($id_users){
            $result =$result->where('student.id_user', $id_users);
        }
        
        if ($id_year){
            $result =$result->where('student.id_year', $id_year);
        }
        if($course_name){
            $result =$result->where('student.course_name', $course_name);
        }
        if ($total) {
            return $result->countAllResults();
        }

        if ($query) {
            $result =$result->GroupStart()
            ->Like('student.name', $query)
            ->orLike('student.father_name', $query)          
            ->orLike('student.rollnumber', $query)
            ->orLike('exam_center.name', $query)
            ->orLike('student.nameofschool', $query)
            ->orLike('student.result', $query)
            ->orLike('student.total', $query)
            ->orLike('student.division', $query)
            ->GroupEnd();
        }

        return $result->orderBy('exam_center.name ASC')->get($limit, $offset)->getResult();

        // echo (string)$this->getLastQuery();
        // exit;
    }

    public function getDashboardDetails()
    {
        $result = $this->db->query("SELECT y.name, r.gender, r.total, r.month FROM year y LEFT JOIN (
        SELECT id_year, CASE WHEN gender = 1 THEN 'male' ELSE 'female' END AS gender, count(*) AS total, course_month AS month 
        FROM student GROUP BY id_year, gender, course_month)
        r on r.id_year = y.id_year")->getResult();

        $year_gender_count = [];
                 
        foreach ($result as $key => $result_row) {
            
            if (!isset($year_gender_count[$result_row->name][$result_row->month])) {
                $year_gender_count[$result_row->name][$result_row->month] = [];
                    
            }

            $year_gender_count[$result_row->name][$result_row->month][$result_row->gender] = $result_row->total;
                         
        }

        
        return $year_gender_count;
    }
}
