<?php

namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes();

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (file_exists(SYSTEMPATH . 'Config/Routes.php')) {
    require SYSTEMPATH . 'Config/Routes.php';
}

/*
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
$routes->setDefaultController('Login');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(false);
$routes->set404Override();
$routes->setAutoRoute(true);

/*
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
$routes->get('/', 'Login::index');
$routes->get('/login', 'Login::index');
$routes->get('/admin', 'Admin::index', ['filter' => 'auth']);
$routes->get('/user', 'Home::index', ['filter' => 'auth']);
$routes->group('admin', ['filter' => 'auth'], function($routes) {
	$routes->add('manage/(:any)', 'Admin::manage/$1');
	$routes->add('manage/(:any)/(:num)', 'Admin::manage/$1/$2');
	$routes->add('delete/(:any)/(:any)', 'Admin::delete/$1/$2');
});
$routes->group('user', ['filter' => 'auth'], function($routes) {
	$routes->add('index','Home::index');
	$routes->add('manage/(:any)', 'Home::manage/$1');
	$routes->add('manage/(:any)/(:num)', 'Home::manage/$1/$2');
	$routes->add('delete/(:any)/(:any)', 'Home::delete/$1/$2');
});
$routes->group('ajax', ['filter' => 'auth'], function($routes) {
	$routes->add('get/(:any)', 'Ajax::get/$1');
});


/*
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need it to be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (file_exists(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php')) {
    require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
